import os

from yaml import safe_load as load_yaml


def override(settings, yaml=None, env=None):
    """
    :param dict settings: settings dict to be updated; usually it's ``globals()``
    :param yaml: path to YAML file
    :type yaml: str or FileIO
    :param str env: prefix for environment variables
    """
    if yaml is not None:
        if hasattr(yaml, 'read'):
            settings.update(load_yaml(yaml.read()))
        else:
            if os.path.exists(yaml):
                with open(yaml) as f:
                    settings.update(load_yaml(f.read()))

    if env is not None:
        for k, v in os.environ.items():
            if k.startswith(env):
                settings[k[len(env):]] = load_yaml(v)



from setuptools import setup


setup(
    name='settings-overrider',
    version='1.0.0',
    description='Override Python dict contents with YAML file and/or environment variables',
    long_description=(
        'Originally created for Django settings but may be useful in other cases. '
        'Read more on `project\'s GitHub page '
        '<https://github.com/kottenator/settings-overrider>`_.'
    ),
    url='https://github.com/kottenator/settings-overrider',
    author='Rostyslav Bryzgunov',
    author_email='kottenator@gmail.com',
    license='MIT',
    py_modules=['settings_overrider'],
    install_requires=['PyYAML'],
    extras_require={
        'test': [
            'pytest',
            'pytest-cov'
        ]
    },
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3'
    ]
)
